@@ -8,6 +8,13 @@ rm_ansi_codes = partial(rec(
 ).sub, '')
 
 
+# make valid name
+clean_name_re = partial(rec(r'\W').sub, '_')
+
+def clean_name(txt):
+    return clean_name_re(txt).strip('_')
+
+
 # Convert file permissions from str to oct
 def oct_mod(str_mod):
     assert len(str_mod)==9, f'bad mode : {str_mod} ({len(str_mod)})'
